@@ -22,7 +22,7 @@ engine_to_cluster_parameter_group_family = {
     "legacy-aurora-mysql": "default.aurora5.6",
     "aurora-mysql": "default.aurora-mysql5.7",
     "aurora-postgresql": "default.aurora-postgresql9.6",
-    "oracle_s2": "default.oracle-se2-12-2",
+    "oracle_s2": "default.oracle-se2-19",
     "oracle_ee": "default.oracle-ee-19",
     "mysql": "default.mysql5.7",
     "postgresql" : None
