@@ -128,6 +128,10 @@ class Microservice(core.Construct):
 
         network_load_balancer_source_autoscaling_group (Optional | aws_autoscaling.AutoScalingGroup): the asg that can communicate with the nlb machines
 
+        stickiness_cookie_duration_in_hours: (Optinal | str) if provided sticky sessions will be configured for the Application Load Balancer.
+
+        load_balancer_idle_timeout_in_seconds: (Optional | str) if provided idle timeout will be  configured for the Application Load Balancer.
+
     """
 
     @property
@@ -320,6 +324,7 @@ class Microservice(core.Construct):
         ec2_traffic_port,
         ec2_health_check_path,
         protocol=_alb.ApplicationProtocol.HTTP,
+        stickiness_cookie_duration_in_hours=None,
     ):
         """Create a Target Group object
         
@@ -334,6 +339,8 @@ class Microservice(core.Construct):
             
             protocol (aws_alb.ApplicationProtocol): Default=_alb.ApplicationProtocol.HTTP. The protocol the target group uses to receive traffic
         
+            stickiness_cookie_duration_in_hours: (Optinal | str) if provided sticky sessions will be configured for the Application Load Balancer.
+            
         Returns:
             aws_ec2.SecurityGroup: the provided security group
         """ 
@@ -346,6 +353,7 @@ class Microservice(core.Construct):
             vpc=self._vpc,
             target_type=_alb.TargetType.INSTANCE,
             target_group_name=(app_name + id + "-tg").replace("_", "-"),
+            stickiness_cookie_duration=core.Duration.hours(int(stickiness_cookie_duration_in_hours)) if stickiness_cookie_duration_in_hours else None,
         )
         tg.configure_health_check(
             enabled=True,
@@ -392,7 +400,7 @@ class Microservice(core.Construct):
 
         return nlb
 
-    def create_load_balancer(self, scope, id, app_name, environment, environments_parameters, security_group=None, internet_facing=False, load_balancer_name=None, use_cdn=False, main_component_name=None):
+    def create_load_balancer(self, scope, id, app_name, environment, environments_parameters, security_group=None, internet_facing=False, load_balancer_name=None, use_cdn=False, main_component_name=None, load_balancer_idle_timeout_in_seconds=None):
         """Create a Load Balancer resource
         
         Args:
@@ -409,12 +417,16 @@ class Microservice(core.Construct):
 
             main_component_name (Optional | str): This is just a metadata. Textually specify the component the EC2 instance will host (e.g. tomcat, drupal, ...)
 
+            load_balancer_idle_timeout_in_seconds: (Optional | str) if provided idle timeout will be  configured for the Application Load Balancer. (Default is 50s)
     
         Returns:
             aws_alb.ApplicationLoadBalancer: the newly created Load Balancer
         """ 
         if load_balancer_name is None:
             load_balancer_name = id
+        
+        if load_balancer_idle_timeout_in_seconds is None:
+            load_balancer_idle_timeout_in_seconds = '50'
 
         # In case CDN is in use, create a new Security Group with access
         # Only from Cloudflare and replace the provided Security Group with the newly 
@@ -477,7 +489,7 @@ class Microservice(core.Construct):
             load_balancer_name=load_balancer_name,
             vpc=self.vpc,
             internet_facing=internet_facing,
-            idle_timeout=core.Duration.seconds(50),
+            idle_timeout=core.Duration.seconds(int(load_balancer_idle_timeout_in_seconds)),
             security_group=security_group,
         )
 
@@ -650,6 +662,8 @@ class Microservice(core.Construct):
         network_load_balancer_subnet_1=None,
         network_load_balancer_subnet_2=None,
         network_load_balancer_source_autoscaling_group=None,
+        stickiness_cookie_duration_in_hours=None,
+        load_balancer_idle_timeout_in_seconds=None,
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
@@ -845,7 +859,7 @@ class Microservice(core.Construct):
             )
         else:
             self._tg = self.create_target_group(
-                main_component_name, app_name, environment, ec2_traffic_port, ec2_health_check_path, protocol=ec2_traffic_protocol
+                main_component_name, app_name, environment, ec2_traffic_port, ec2_health_check_path, protocol=ec2_traffic_protocol, stickiness_cookie_duration_in_hours=stickiness_cookie_duration_in_hours
             )
 
         if(is_application_load_balancer):
@@ -934,7 +948,8 @@ class Microservice(core.Construct):
                 internet_facing=is_public, 
                 load_balancer_name='-'.join([app_name, main_component_name, 'alb']), 
                 use_cdn=use_cdn,
-                main_component_name=main_component_name
+                main_component_name=main_component_name,
+                load_balancer_idle_timeout_in_seconds=load_balancer_idle_timeout_in_seconds
             )
         
         if(is_application_load_balancer):
@@ -1309,6 +1324,7 @@ class Microservice(core.Construct):
             vpc=self._vpc,
             vpc_subnets=vpc_subnets if create_ebs else None,
             cooldown=core.Duration.seconds(120),
+            min_capacity=2 if is_ha else 1,
             max_capacity=int(autoscaling_group_max_size),
             allow_all_outbound=True,
             health_check=_asg.HealthCheck.elb(grace=core.Duration.minutes(10)),
